﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using RunTimeLocalization.Reports;
using GrapeCity.ActiveReports;
using GrapeCity.ActiveReports.SectionReportModel;
using System.Reflection;
namespace RunTimeLocalization
{
    public partial class Form1 : Form
    {
        class ReportDef
        {
            public Dictionary<string, Dictionary<string, object>> LanguageDictionaries { get; set; }
            public string ReportName { get; set; }
        }
        string SelectedLanguage { get; set; }
        List<ReportDef> rptdefs = new List<ReportDef>();

        public Form1()
        {
            InitializeComponent();
            rptdefs = new List<ReportDef>()
            {
                new ReportDef() {ReportName="NewActiveReport1", LanguageDictionaries = new Dictionary<string, Dictionary<string, object>>() },
                new ReportDef() { ReportName = "NewActiveReport2", LanguageDictionaries = new Dictionary<string, Dictionary<string, object>>() }
            };

            this.cmbReports.SelectedIndexChanged += (s, ea) =>
                {
                    ReportDef rptdef = rptdefs.Where(t => t.ReportName == cmbReports.SelectedItem.ToString()).ToList()[0];
                    cmbLanguage.Items.Clear();
                    if (rptdef.LanguageDictionaries.Count > 0)
                    {
                        for (int i = 0; i < rptdef.LanguageDictionaries.Count; i++)
                        {
                            cmbLanguage.Items.Add(rptdef.LanguageDictionaries.Keys.ToArray()[i]);
                        }
                    }
                    this.cmbLanguage.SelectedItem = "English";
                };

            this.cmbLanguage.SelectedIndexChanged += (s, ea) =>
                {
                    ReportDef rptdef = rptdefs.Where(t => t.ReportName == cmbReports.SelectedItem.ToString()).ToList()[0];
                    SectionReport rpt = SetLocaleStringsToReport(rptdef.LanguageDictionaries[cmbLanguage.SelectedItem.ToString()], cmbReports.SelectedItem.ToString());
                    viewer1.LoadDocument(rpt);
                };

            this.btnLocalize.Click += (s, ea) =>
                {
                    LocalizeProperties localizeProps = new LocalizeProperties();
                    ReportDef rptdef = rptdefs.Where(t => t.ReportName == cmbReports.SelectedItem.ToString()).ToList()[0];
                    localizeProps.EnglishDiction = rptdef.LanguageDictionaries["English"];

                    if (localizeProps.ShowDialog() == DialogResult.OK)
                    {
                        string language = localizeProps.Language;
                        rptdef.LanguageDictionaries.Add(language, localizeProps.LocaleDiction);
                        cmbLanguage.Items.Add(language);
                        cmbLanguage.SelectedItem = language;
                    }
                };
        }

        private SectionReport SetLocaleStringsToReport(Dictionary<string, object> LocalDiction, string ReportName)
        {
            GrapeCity.ActiveReports.SectionReport Report = new GrapeCity.ActiveReports.SectionReport();
            if (ReportName == "NewActiveReport1")
            {
                Report = new NewActiveReport1();
            }
            else
                Report = new NewActiveReport2();

            foreach (Section section in Report.Sections)
            {
                foreach (ARControl control in section.Controls)
                {
                    if (LocalDiction.Keys.Contains(control.Name))
                    {
                        if (LocalDiction[control.Name].ToString() != "")
                        {
                            PropertyInfo textProp = control.GetType().GetProperty("Text");
                            textProp.SetValue(control, LocalDiction[control.Name].ToString(), null);
                        }
                    }
                }
            }
            return Report;
        }

        private Dictionary<string, object> GetEnglishDictionOfReport(string ReportName)
        {
            Dictionary<string, object> EnglishDiction = new Dictionary<string, object>();

            GrapeCity.ActiveReports.SectionReport Report = new GrapeCity.ActiveReports.SectionReport();
            if (ReportName == "NewActiveReport1")
            {
                Report = new NewActiveReport1();
            }
            else
                Report = new NewActiveReport2();

            foreach (Section section in Report.Sections)
            {
                foreach (ARControl control in section.Controls)
                {
                    PropertyInfo textProp = control.GetType().GetProperty("Text");
                    if (textProp != null)
                    {
                        try
                        {
                            string text = textProp.GetValue(control, null).ToString();
                            EnglishDiction.Add(control.Name, text);
                        }
                        catch { }
                    }
                }
            }
            return EnglishDiction;
        }
        private void Form1_Load(object sender, EventArgs e)
        {
            rptdefs[0].LanguageDictionaries.Add("English", GetEnglishDictionOfReport("NewActiveReport1"));
            rptdefs[1].LanguageDictionaries.Add("English", GetEnglishDictionOfReport("NewActiveReport2"));
            cmbReports.SelectedItem = "NewActiveReport1";
        }
    }
}
